diff libpurple/notify.h @ 32368:6283c0f2b02f

Change PurpleNotifyUserInfo->user_info_entries from a GList to a GQueue. This makes appending fast.
author Mark Doliner <mark@kingant.net>
date Mon, 22 Aug 2011 04:14:16 +0000
parents 99ca503ea087
children 0cc718e10344
line wrap: on
line diff
--- a/libpurple/notify.h	Mon Aug 22 03:40:04 2011 +0000
+++ b/libpurple/notify.h	Mon Aug 22 04:14:16 2011 +0000
@@ -439,20 +439,20 @@
  * Retrieve the array of PurpleNotifyUserInfoEntry objects from a
  * PurpleNotifyUserInfo
  *
  * This GList may be manipulated directly with normal GList functions such
  * as g_list_insert(). Only PurpleNotifyUserInfoEntry are allowed in the
  * list.  If a PurpleNotifyUserInfoEntry item is added to the list, it
  * should not be g_free()'d by the caller; PurpleNotifyUserInfo will g_free
  * it when destroyed.
  *
  * To remove a PurpleNotifyUserInfoEntry, use
  * purple_notify_user_info_remove_entry(). Do not use the GList directly.
  *
  * @param user_info  The PurpleNotifyUserInfo
  *
  * @constreturn A GList of PurpleNotifyUserInfoEntry objects
  */
-GList *purple_notify_user_info_get_entries(PurpleNotifyUserInfo *user_info);
+GQueue *purple_notify_user_info_get_entries(PurpleNotifyUserInfo *user_info);
 
 /**
  * Create a textual representation of a PurpleNotifyUserInfo, separating
@@ -439,20 +439,20 @@
  * PurpleNotifyUserInfo
  *
- * This GList may be manipulated directly with normal GList functions such
- * as g_list_insert(). Only PurpleNotifyUserInfoEntry are allowed in the
- * list.  If a PurpleNotifyUserInfoEntry item is added to the list, it
- * should not be g_free()'d by the caller; PurpleNotifyUserInfo will g_free
- * it when destroyed.
+ * This GQueue may be manipulated directly with normal GQueue functions such
+ * as g_queue_push_tail(). Only PurpleNotifyUserInfoEntry are allowed in the
+ * queue.  If a PurpleNotifyUserInfoEntry item is added to the queue, it
+ * should not be freed by the caller; PurpleNotifyUserInfo will free it when
+ * destroyed.
  *
  * To remove a PurpleNotifyUserInfoEntry, use
@@ -439,20 +439,20 @@
  *
  * To remove a PurpleNotifyUserInfoEntry, use
- * purple_notify_user_info_remove_entry(). Do not use the GList directly.
+ * purple_notify_user_info_remove_entry(). Do not use the GQueue directly.
  *
  * @param user_info  The PurpleNotifyUserInfo
@@ -439,20 +439,20 @@
  * @param user_info  The PurpleNotifyUserInfo
  *
- * @constreturn A GList of PurpleNotifyUserInfoEntry objects
+ * @constreturn A GQueue of PurpleNotifyUserInfoEntry objects.
  */